WaitingPage
=================================

.. currentmodule:: alfred3_interact.page

.. autoclass:: WaitingPage
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~WaitingPage.added_to_experiment


      ~WaitingPage.added_to_section


      ~WaitingPage.append


      ~WaitingPage.close


      ~WaitingPage.custom_move


      ~WaitingPage.durations


      ~WaitingPage.first_duration


      ~WaitingPage.last_duration


      ~WaitingPage.on_close


      ~WaitingPage.on_each_hide


      ~WaitingPage.on_each_show


      ~WaitingPage.on_exp_access


      ~WaitingPage.on_expire


      ~WaitingPage.on_first_hide


      ~WaitingPage.on_first_show


      ~WaitingPage.position_in_section


      ~WaitingPage.prepare_web_widget


      ~WaitingPage.save_data


      ~WaitingPage.showif


      ~WaitingPage.uptree


      ~WaitingPage.validate


      ~WaitingPage.visible


      ~WaitingPage.wait_for







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~WaitingPage.all_elements
         ~WaitingPage.all_input_elements
         ~WaitingPage.background_color
         ~WaitingPage.data
         ~WaitingPage.elements
         ~WaitingPage.exp
         ~WaitingPage.experiment
         ~WaitingPage.expiration_time
         ~WaitingPage.expired
         ~WaitingPage.filled_input_elements
         ~WaitingPage.fixed_width
         ~WaitingPage.footer_text
         ~WaitingPage.has_been_shown
         ~WaitingPage.header_color
         ~WaitingPage.input_elements
         ~WaitingPage.instance_log
         ~WaitingPage.is_closed
         ~WaitingPage.minimum_display_time
         ~WaitingPage.minimum_display_time_msg
         ~WaitingPage.must_be_shown
         ~WaitingPage.name
         ~WaitingPage.parent
         ~WaitingPage.parent_name
         ~WaitingPage.passed_time
         ~WaitingPage.prefix_element_names
         ~WaitingPage.progress
         ~WaitingPage.responsive_width
         ~WaitingPage.section
         ~WaitingPage.short_tree
         ~WaitingPage.should_be_shown
         ~WaitingPage.subtitle
         ~WaitingPage.tag
         ~WaitingPage.title
         ~WaitingPage.tree
         ~WaitingPage.uid
         ~WaitingPage.unlinked_data
         ~WaitingPage.updated_elements
         ~WaitingPage.vargs
         ~WaitingPage.wait_exception_page
         ~WaitingPage.wait_msg
         ~WaitingPage.wait_sleep_time
         ~WaitingPage.wait_timeout
         ~WaitingPage.wait_timeout_page
         ~WaitingPage.waiting_start
